@@ -238,18 +238,29 @@ class Bucket(core.Construct):
                 "198.41.128.0/17",
             ]
 
+            # Only allow access from Cloudflare IPs
             self.bucket.add_to_resource_policy(
                 _iam.PolicyStatement(
                     effect=_iam.Effect.DENY,
                     principals=[_iam.Anyone()],
                     actions=["s3:GetObject"],
                     resources=[
-                        "arn:aws:s3:::" + bucket_name,
                         "arn:aws:s3:::" + bucket_name + "/*",
                     ],
                     conditions={"NotIpAddress": {"aws:SourceIp": cloudflare_ips}},
                 )
             )
+            self.bucket.add_to_resource_policy(
+                _iam.PolicyStatement(
+                    effect=_iam.Effect.ALLOW,
+                    principals=[_iam.Anyone()],
+                    actions=["s3:GetObject"],
+                    resources=[
+                        "arn:aws:s3:::" + bucket_name + "/*",
+                    ],
+                    conditions={"IpAddress": {"aws:SourceIp": cloudflare_ips}},
+                )
+            )
 
             self.bucket.add_cors_rule(
                 allowed_methods=[
