@@ -61,7 +61,7 @@ class Microservice(core.Construct):
 
         ebs_volume_size (str): In case you want to create a secondary EBS volume for your EC2 instance, this parameter is used to specify the volume size. The parameter specify the desired GB. Only use this parameter when your system cannot horizontally scale!
 
-        ec2_ami_id (str): Specify the EC2 AMI id to use to create the EC2 instance. In no value is specified the laster Linux Hardened AMI will be used.
+        ec2_ami_id (str): Specify the EC2 AMI id to use to create the EC2 instance. Use "LATEST" the use laster Linux Hardened AMI.
 
         ec2_health_check_path (str):  Specify the Target Group health check path to use to monitor the state of the EC2 instances. EC2 instances will be constantly monitored, performing requests to this path. The request must receive a successful response code to consider the EC2 healthy. Otherwise the EC2 will be terminated and regenerated. It must start with a slash "/"
 
@@ -108,6 +108,12 @@ class Microservice(core.Construct):
         existing_efs_security_group (str): In case you want to enble access to an existing EFS, provide its security group resource. If provided, `existing_efs_security_group_id` will be ignored
         
         existing_efs_security_group_id (str): In case you want to enble access to an existing EFS, provide its already-existing security group ID. If `existing_efs_security_group`, this will be ignored. Important: `existing_efs_security_group_id` works only if the Security Group is already existing and deployed on AWS. Not compabible with security groups created during the first deployment.
+
+        tag_scheduler_uptime (str): specifies the time range in which the AWS resource should be kept up and running - format `HH:mm-HH:mm` (i.e. 'start'-'end'), where the 'start' time must be before 'end'
+        
+        tag_scheduler_uptime_days (str): weekdays in which the `SchedulerUptime` tag should be enforced. If not specified, `SchedulerUptime` will be enforced during each day of the week - format integer from 1 to 7, where 1 is Monday
+        
+        tag_scheduler_uptime_skip (str): to skip optimization check - format Boolean (`true`, `false`)
     """
 
     @property
@@ -380,6 +386,14 @@ class Microservice(core.Construct):
             idle_timeout=core.Duration.seconds(50),
             security_group=security_group,
         )
+
+        # Enable access from App Proxy if the Load Balancer is private
+        if internet_facing is False:
+            aws_account = environments_parameters["accounts"][environment.lower()]
+            app_proxy_security_group = _ec2.SecurityGroup.from_security_group_id(
+                self, "upstream_security_group", aws_account["app_proxy_security_group"], mutable=False
+            )
+            alb.add_security_group(app_proxy_security_group)
         
         # Enable logging
         alb.log_access_logs(self._alb_logs_bucket, prefix=self._app_name)
@@ -533,6 +547,9 @@ class Microservice(core.Construct):
         additional_variables: dict = None,
         existing_efs_security_group = None,
         existing_efs_security_group_id = None,
+        tag_scheduler_uptime="",
+        tag_scheduler_uptime_days="",
+        tag_scheduler_uptime_skip="",
         **kwargs
     ):
         super().__init__(scope, id, **kwargs)
@@ -561,7 +578,7 @@ class Microservice(core.Construct):
         is_private = not is_public
 
         is_production = environment == "Production"
-        is_not_procution = not is_production
+        is_not_producution = not is_production
 
         has_upstream = not not upstream_security_group
         has_not_upstream = not has_upstream
@@ -638,8 +655,6 @@ class Microservice(core.Construct):
             will_use_ldap and isinstance(will_use_ldap, str) and will_use_ldap.lower() == "true"
         )
 
-        
-
         # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Validate input params
 
         if has_additional_variables and type(additional_variables) is not dict:
@@ -683,7 +698,7 @@ class Microservice(core.Construct):
         )
         if has_upstream:
             upstream_security_group_as_peer = _ec2.SecurityGroup.from_security_group_id(
-                self, "upstream_security_group", upstream_security_group, mutable=True
+                self, "upstream_security_group_"+main_component_name, upstream_security_group, mutable=True
             )
 
         # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Create AWS resources
@@ -1105,7 +1120,7 @@ class Microservice(core.Construct):
         # ~~~~~~~~~~~~~~~~
         # Auto Scaling Group
         # ~~~~~~~~~~~~~~~~
-        if not ec2_ami_id:
+        if ec2_ami_id == "LATEST":
             ec2_ami_id = _ssm.StringParameter.value_for_string_parameter(
             self, "/common/linuxHardenedAmi/latest")
 
@@ -1171,6 +1186,18 @@ class Microservice(core.Construct):
             ],
         )
 
+        # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ FAO AWS Scheduler tags
+        if is_not_producution:
+            ASG = self._asg.node.find_child("ASG")
+            if tag_scheduler_uptime_skip:
+                Tags.of(ASG).add("SchedulerSkip", tag_scheduler_uptime_skip, apply_to_launched_instances=True,)
+
+            if tag_scheduler_uptime:
+                Tags.of(ASG).add("SchedulerUptime", tag_scheduler_uptime, apply_to_launched_instances=True,)
+
+            if tag_scheduler_uptime_days:
+                Tags.of(ASG).add("SchedulerUptimeDays", tag_scheduler_uptime_days, apply_to_launched_instances=True,)   
+
         # Configure the CFT signal to user data. To overcome the issue that the
         # ASG Logical Id cannot is hard to retrieve, let override it (easier withe the current CDK version)
         # and pass the fixed ASG logical Id as param of the CFN signal
