@@ -89,7 +89,7 @@ class ServiceUserForIAC(core.Construct):
                         "ec2:CreateSecurityGroup",
                         "ec2:*SecurityGroup*",
                         "ec2:Describe*",
-                        "ec2:createTags*",
+                        "ec2:*Tag*",
                         "serverlessrepo:SearchApplications",
                         "serverlessrepo:GetApplication",
                         "serverlessrepo:*CloudFormationTemplate",
