@@ -42,14 +42,14 @@ class ServiceUserForStaticAssets(core.Construct):
 
         # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Create AWS resources
 
-        service_user = _iam.User(
+        self._service_user = _iam.User(
             self,
             "service_user",
             managed_policies=None,
             user_name="SRVUSR-" + app_name + "_" + environment + "_static_assets",
         )
 
-        service_user.add_managed_policy(
+        self._service_user.add_managed_policy(
             _iam.ManagedPolicy(
                 self,
                 "service_user_policies",
@@ -82,19 +82,20 @@ class ServiceUserForStaticAssets(core.Construct):
             )
         )
 
-        service_user.add_managed_policy(
-            _iam.ManagedPolicy(
-                self,
-                "service_user_s3_code_bucket_policies",
-                statements=[
-                    # S3 Assets bucket permissions
-                    _iam.PolicyStatement(
-                        actions=["s3:*"],
-                        resources=[
-                            "arn:aws:s3:::" + s3_bucket_name,
-                            "arn:aws:s3:::" + s3_bucket_name + "/*",
-                        ],
-                    ),
-                ],
-            )
-        )
\ No newline at end of file
+        if s3_bucket_name:
+            self._service_user.add_managed_policy(
+                _iam.ManagedPolicy(
+                    self,
+                    "service_user_s3_code_bucket_policies",
+                    statements=[
+                        # S3 Assets bucket permissions
+                        _iam.PolicyStatement(
+                            actions=["s3:*"],
+                            resources=[
+                                "arn:aws:s3:::" + s3_bucket_name,
+                                "arn:aws:s3:::" + s3_bucket_name + "/*",
+                            ],
+                        ),
+                    ],
+                )
+            )
\ No newline at end of file
